@@ -1060,6 +1060,15 @@ class TestKDEPlotBivariate:
         for c in ax.collections:
             assert_colors_equal(get_contour_color(c), color)
 
+    def test_contour_line_cmap(self, long_df):
+
+        color_list = color_palette("Blues", 12)
+        cmap = mpl.colors.ListedColormap(color_list)
+        ax = kdeplot(data=long_df, x="x", y="y", cmap=cmap)
+        for c in ax.collections:
+            color = to_rgb(get_contour_color(c).squeeze())
+            assert color in color_list
+
     def test_contour_fill_colors(self, long_df):
 
         n = 6
@@ -1421,8 +1430,8 @@ class TestHistPlotUnivariate(SharedAxesLevelTests):
             bars = bar_groups[i]
             start = bars[0].get_x()
             stop = bars[-1].get_x() + bars[-1].get_width()
-            assert start == wide_df[col].min()
-            assert stop == wide_df[col].max()
+            assert_array_almost_equal(start, wide_df[col].min())
+            assert_array_almost_equal(stop, wide_df[col].max())
 
     def test_weights_with_missing(self, missing_df):
 
@@ -1559,14 +1568,14 @@ class TestHistPlotUnivariate(SharedAxesLevelTests):
 
     def test_kde_singular_data(self):
 
-        with pytest.warns(None) as record:
+        with warnings.catch_warnings():
+            warnings.simplefilter("error")
             ax = histplot(x=np.ones(10), kde=True)
-        assert not record
         assert not ax.lines
 
-        with pytest.warns(None) as record:
+        with warnings.catch_warnings():
+            warnings.simplefilter("error")
             ax = histplot(x=[5], kde=True)
-        assert not record
         assert not ax.lines
 
     def test_element_default(self, long_df):
