@@ -1,4 +1,6 @@
 from itertools import product
+import warnings
+
 import numpy as np
 import matplotlib as mpl
 import matplotlib.pyplot as plt
@@ -1068,6 +1070,15 @@ class TestLinePlotter(SharedAxesLevelTests, Helpers):
         ax.clear()
         p.plot(ax, {})
 
+    def test_non_aggregated_data(self):
+
+        x = [1, 2, 3, 4]
+        y = [2, 4, 6, 8]
+        ax = lineplot(x=x, y=y)
+        line, = ax.lines
+        assert_array_equal(line.get_xdata(), x)
+        assert_array_equal(line.get_ydata(), y)
+
     def test_orient(self, long_df):
 
         long_df = long_df.drop("x", axis=1).rename(columns={"s": "y", "y": "x"})
@@ -1735,9 +1746,9 @@ class TestScatterPlotter(SharedAxesLevelTests, Helpers):
 
     def test_unfilled_marker_edgecolor_warning(self, long_df):  # GH2636
 
-        with pytest.warns(None) as record:
+        with warnings.catch_warnings():
+            warnings.simplefilter("error")
             scatterplot(data=long_df, x="x", y="y", marker="+")
-        assert not record
 
     def test_scatterplot_vs_relplot(self, long_df, long_semantics):
 
